@@ -1,10 +1,14 @@
 from firestore_collections.collection import Collection
 from firestore_collections.enums import OrderByDirection
-from firestore_collections.schema import Schema
+from firestore_collections.schema import (
+    Schema,
+    SchemaWithOwner,
+)
 
 
 __all__ = [
     'Collection',
     'OrderByDirection',
     'Schema',
+    'SchemaWithOwner',
 ]
